==> tooluniverse-1.0.12.2.tar.gz: tooluniverse-1.0.12.2/src/tooluniverse/tools/FAERS_count_country_by_drug_event.py <==
"""
FAERS_count_country_by_drug_event

Count the number of adverse event reports per country of occurrence, filtered by drug, patient de...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def FAERS_count_country_by_drug_event(
    medicinalproduct: str,
    patientsex: str,
    patientagegroup: str,
    serious: str,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Count the number of adverse event reports per country of occurrence, filtered by drug, patient de...

    Parameters
    ----------
    medicinalproduct : str
        Drug name.
    patientsex : str
        Patient sex, leave it blank if you don't want to apply a filter.
    patientagegroup : str
        Patient age group.
    serious : str
        Whether the event was serious.
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "FAERS_count_country_by_drug_event",
            "arguments": {
                "medicinalproduct": medicinalproduct,
                "patientsex": patientsex,
                "patientagegroup": patientagegroup,
                "serious": serious,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["FAERS_count_country_by_drug_event"]

==> tooluniverse-1.0.12.7.tar.gz: tooluniverse-1.0.12.7/src/tooluniverse/tools/FAERS_count_country_by_drug_event.py <==
"""
FAERS_count_country_by_drug_event

Count the number of adverse event reports per country of occurrence. Only medicinalproduct is req...
"""

from typing import Any, Optional, Callable
from ._shared_client import get_shared_client


def FAERS_count_country_by_drug_event(
    medicinalproduct: str,
    patientsex: Optional[str] = None,
    patientagegroup: Optional[str] = None,
    serious: Optional[str] = None,
    *,
    stream_callback: Optional[Callable[[str], None]] = None,
    use_cache: bool = False,
    validate: bool = True,
) -> Any:
    """
    Count the number of adverse event reports per country of occurrence. Only medicinalproduct is req...

    Parameters
    ----------
    medicinalproduct : str
        Drug name.
    patientsex : str
        Optional: Filter by patient sex. Omit this parameter if you don't want to fil...
    patientagegroup : str
        Optional: Filter by patient age group. Omit this parameter if you don't want ...
    serious : str
        Optional: Filter by event seriousness. Omit this parameter if you don't want ...
    stream_callback : Callable, optional
        Callback for streaming output
    use_cache : bool, default False
        Enable caching
    validate : bool, default True
        Validate parameters

    Returns
    -------
    Any
    """
    # Handle mutable defaults to avoid B006 linting error

    return get_shared_client().run_one_function(
        {
            "name": "FAERS_count_country_by_drug_event",
            "arguments": {
                "medicinalproduct": medicinalproduct,
                "patientsex": patientsex,
                "patientagegroup": patientagegroup,
                "serious": serious,
            },
        },
        stream_callback=stream_callback,
        use_cache=use_cache,
        validate=validate,
    )


__all__ = ["FAERS_count_country_by_drug_event"]
